EmergenzScanner | unified-mandala - v1.0.0
Description: Documentation for unified-mandala

# Class EmergenzScanner

- Defined in packages/crep-engine/EmergenzScanner.ts:4

#####
Index

### Constructors

constructor

### Properties

crepManager

### Methods

scanForEmergence

## Constructors

### constructor

- new EmergenzScanner(crepManager): EmergenzScanner

- #### Parameters

  - crepManager: CREPManager

  #### Returns EmergenzScanner

  - Defined in packages/crep-engine/EmergenzScanner.ts:5

## Properties

### `Private` crepManager

crepManager: CREPManager

- Defined in packages/crep-engine/EmergenzScanner.ts:5

## Methods

### scanForEmergence

- scanForEmergence(): boolean

- #### Returns boolean

  - Defined in packages/crep-engine/EmergenzScanner.ts:7